@@ -474,6 +474,8 @@ class SpecSlot():
                              **self.imKwargs,
                              )
         self.img = img
+        self.current_time = (sig.t_start.rescale('s'),
+                             sig.t_stop.rescale('s'))
 
     def CalcAvarage(self, TimeAvg, TimesEvent, Units=None, **Kwargs):
 
@@ -716,6 +718,8 @@ class ControlFigure():
 
         self.pltSL = pltSL
 
+        self.pltSLFigs = set([ax.get_figure() for ax in pltSL.Axs])
+
         self.MapSlots = []
         for sl in pltSL.Slots:
             if hasattr(sl, 'Map'):
@@ -856,7 +860,8 @@ class ControlFigure():
 
     def UpdateGraph(self, twind):
         self.pltSL.PlotChannels(twind)
-        self.pltSL.Fig.canvas.draw()
+        for f in self.pltSLFigs:
+            f.canvas.draw()
 
     def submit_start(self, text):
         try:
@@ -983,11 +988,6 @@ class PlotSlots():
 
         self.ScaleBarAx = ScaleBarAx
 
-        if LiveControl:
-            self.CtrFig = ControlFigure(self)
-        else:
-            self.CtrFig = None
-
         if Fig is None:
             self._GenerateFigure()
         else:
@@ -1002,12 +1002,23 @@ class PlotSlots():
 
         self.TimeAxis = TimeAxis
         if self.TimeAxis is not None:
-            sl = self.Slots[TimeAxis]
-            sl.UpdateAxKwargs(self.TimeAxisProp)
+            if hasattr(TimeAxis, '__iter__'):
+                for ti in TimeAxis:
+                    sl = self.Slots[TimeAxis]
+                    sl.UpdateAxKwargs(self.TimeAxisProp)            
+            else:
+                sl = self.Slots[TimeAxis]
+                sl.UpdateAxKwargs(self.TimeAxisProp)
 
         UpdateTreeDictProp(self.Fig, self.FigKwargs)
         self.SortSlotsAx()
 
+        if LiveControl:
+            self.CtrFig = ControlFigure(self)
+        else:
+            self.CtrFig = None
+
+
     def SortSlotsAx(self):
         self.SlotsInAxs = {}
         for ax in self.Axs:
@@ -1156,7 +1167,7 @@ class ImgSlot():
         else:
             Tstart = Time[0]
 
-        if Time[0] > self.Signal.t_stop:
+        if Tstart > self.Signal.t_stop:
             Tstart = self.Signal.t_stop - 2*self.Signal.sampling_period
 
         return (Tstart, Tstart+ self.Signal.sampling_period)
