@@ -19,6 +19,7 @@ from scipy.stats.mstats import zscore
 from . import DbgFplt
 from scipy.interpolate import UnivariateSpline
 from scipy.signal import medfilt
+import elephant
 
 
 def Spectrogram(sig, Fres=2*pq.Hz, TimeRes=0.01*pq.s,
@@ -294,12 +295,13 @@ def sliding_window(sig, timewidth, func=None, steptime=None, **kwargs):
                         sampling_rate=1/steptime)
 
 
-def ThresholdTrianGen(sig, RelaxTime=0.4*pq.s, threshold=None):
+def ThresholdTrianGen(sig, RelaxTime=0.4*pq.s, threshold=None, sign='below'):
 
     if threshold is None:
         threshold = np.mean(sig) + np.std(sig)
     inttimes = Ran.threshold_detection(signal=sig,
                                        threshold=threshold,
+                                       sign=sign,
                                        RelaxTime=RelaxTime)
     inttimes = np.array(inttimes)
 
@@ -310,36 +312,36 @@ def ThresholdTrianGen(sig, RelaxTime=0.4*pq.s, threshold=None):
                       )
 
 
-# def ThresholdInstantRate(sig, RelaxTime=0.1*pq.s, threshold=None,
-#                          OutSampling=0.01*pq.s,):
+def ThresholdInstantRate(sig, RelaxTime=0.1*pq.s, threshold=None,
+                          OutSampling=0.01*pq.s,):
 
 
-#     return elephant.statistics.instantaneous_rate(ThresholdTrianGen(sig,
-#                                                                     RelaxTime,
-#                                                                     threshold),
-#                                                   sampling_period=OutSampling)
+    return elephant.statistics.instantaneous_rate(ThresholdTrianGen(sig,
+                                                                    RelaxTime,
+                                                                    threshold),
+                                                  sampling_period=OutSampling)
 
 
-# def HilbertInstantFreq(sig, MaxFreq=20, MinFreq=0):
-#     SigH = elephant.signal_processing.hilbert(sig)
-#     insfreq = np.diff(np.angle(SigH)[:, 0]) / np.diff(SigH.times)
+def HilbertInstantFreq(sig, MaxFreq=20, MinFreq=0):
+    SigH = elephant.signal_processing.hilbert(sig)
+    insfreq = np.diff(np.angle(SigH)[:, 0]) / np.diff(SigH.times)
 
-#     return AnalogSignal(signal=np.clip(insfreq.magnitude, 0, 20),
-#                      units='Hz',
-#                      name=sig.name,
-#                      sampling_rate=SigH.sampling_rate,
-#                      t_start=SigH.t_start)
+    return AnalogSignal(signal=np.clip(insfreq.magnitude, 0, 20),
+                      units='Hz',
+                      name=sig.name,
+                      sampling_rate=SigH.sampling_rate,
+                      t_start=SigH.t_start)
 
-# def HilbertAngle(sig):
-#     SigH = elephant.signal_processing.hilbert(sig)
-#     return sig.duplicate_with_new_data(signal=np.angle(SigH),
-#                                        units=pq.radians)
+def HilbertAngle(sig):
+    SigH = elephant.signal_processing.hilbert(sig)
+    return sig.duplicate_with_new_data(signal=np.angle(SigH),
+                                        units=pq.radians)
 
 
-# def HilbertAmp(sig):
-#     SigH = elephant.signal_processing.hilbert(sig)
+def HilbertAmp(sig):
+    SigH = elephant.signal_processing.hilbert(sig)
 
-#     return sig.duplicate_with_new_data(signal=np.array(np.abs(SigH))*sig.units)
+    return sig.duplicate_with_new_data(signal=np.array(np.abs(SigH))*sig.units)
 
 
 def SplineSmooth(sig, sFact=2, **kwargs):
